==> android-4.0.1.2-sources.jar: android/widget/AdapterViewFlipper.java <==
package android.widget;
@android.widget.RemoteViews.RemoteView()
public class AdapterViewFlipper
  extends android.widget.AdapterViewAnimator
{
public  AdapterViewFlipper(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  AdapterViewFlipper(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
protected  void onAttachedToWindow() { throw new RuntimeException("Stub!"); }
protected  void onDetachedFromWindow() { throw new RuntimeException("Stub!"); }
protected  void onWindowVisibilityChanged(int visibility) { throw new RuntimeException("Stub!"); }
public  void setAdapter(android.widget.Adapter adapter) { throw new RuntimeException("Stub!"); }
public  void setFlipInterval(int milliseconds) { throw new RuntimeException("Stub!"); }
public  void startFlipping() { throw new RuntimeException("Stub!"); }
public  void stopFlipping() { throw new RuntimeException("Stub!"); }
public  void showNext() { throw new RuntimeException("Stub!"); }
public  void showPrevious() { throw new RuntimeException("Stub!"); }
public  boolean isFlipping() { throw new RuntimeException("Stub!"); }
public  void setAutoStart(boolean autoStart) { throw new RuntimeException("Stub!"); }
public  boolean isAutoStart() { throw new RuntimeException("Stub!"); }
public  void fyiWillBeAdvancedByHostKThx() { throw new RuntimeException("Stub!"); }
}

==> android-4.1.1.4-sources.jar: android/widget/AdapterViewFlipper.java <==
package android.widget;
@android.widget.RemoteViews.RemoteView()
public class AdapterViewFlipper
  extends android.widget.AdapterViewAnimator
{
public  AdapterViewFlipper(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  AdapterViewFlipper(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
protected  void onAttachedToWindow() { throw new RuntimeException("Stub!"); }
protected  void onDetachedFromWindow() { throw new RuntimeException("Stub!"); }
protected  void onWindowVisibilityChanged(int visibility) { throw new RuntimeException("Stub!"); }
public  void setAdapter(android.widget.Adapter adapter) { throw new RuntimeException("Stub!"); }
public  int getFlipInterval() { throw new RuntimeException("Stub!"); }
public  void setFlipInterval(int flipInterval) { throw new RuntimeException("Stub!"); }
public  void startFlipping() { throw new RuntimeException("Stub!"); }
public  void stopFlipping() { throw new RuntimeException("Stub!"); }
public  void showNext() { throw new RuntimeException("Stub!"); }
public  void showPrevious() { throw new RuntimeException("Stub!"); }
public  boolean isFlipping() { throw new RuntimeException("Stub!"); }
public  void setAutoStart(boolean autoStart) { throw new RuntimeException("Stub!"); }
public  boolean isAutoStart() { throw new RuntimeException("Stub!"); }
public  void fyiWillBeAdvancedByHostKThx() { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityEvent(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityNodeInfo(android.view.accessibility.AccessibilityNodeInfo info) { throw new RuntimeException("Stub!"); }
}
